@@ -4,4 +4,5 @@ from .bot_is_ready import bot_is_ready
 from .is_bot_support import is_bot_support
 from .is_voter import is_voter
 from .is_upgrade_chat_subscriber import is_upgrade_chat_subscriber, is_upgrade_chat_purchaser
-from .slash_commands import is_slash_command, is_not_slash_command, bot_in_guild
+
+# from .slash_commands import is_slash_command, is_not_slash_command, bot_in_guild  # todo move this to Novus
