@@ -90,7 +90,7 @@ class Converter(object):
                 return button_check
             try:
                 payload = await ctx.bot.wait_for("component_interaction", check=get_button_check(sent_message), timeout=60.0)
-                await payload.defer_update()
+                await payload.response.defer_update()
             except asyncio.TimeoutError:
                 raise ConverterTimeout(self.timeout_message)
             return await self.converter.convert(ctx, payload)
